==> haskell-hslua-list-1.1.3-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-ClMn8ekEQwLJUjV553C3fe
key:                  hslua-list-1.1.3-ClMn8ekEQwLJUjV553C3fe
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  6d2e809678f351e246540f5b20e2f717
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-ClMn8ekEQwLJUjV553C3fe
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-5G0x5hmdcWo3nepPHPVU6r

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-list-1.1.3-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-L5Y6zLylY61Ht7YopFfgnh
key:                  hslua-list-1.1.3-L5Y6zLylY61Ht7YopFfgnh
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  bb8baf5f9934145c22ccc10a2c967723
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-L5Y6zLylY61Ht7YopFfgnh
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-38rmpo0BEKVLF3MmG72ryb

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
